summaryrefslogtreecommitdiff
path: root/usr/src/uts/common/syscall
diff options
context:
space:
mode:
Diffstat (limited to 'usr/src/uts/common/syscall')
-rw-r--r--usr/src/uts/common/syscall/poll.c5
-rw-r--r--usr/src/uts/common/syscall/times.c13
-rw-r--r--usr/src/uts/common/syscall/uadmin.c5
3 files changed, 10 insertions, 13 deletions
diff --git a/usr/src/uts/common/syscall/times.c b/usr/src/uts/common/syscall/times.c
index cefa942d57..cd268c0c0f 100644
--- a/usr/src/uts/common/syscall/times.c
+++ b/usr/src/uts/common/syscall/times.c
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -20,7 +19,7 @@
* CDDL HEADER END
*/
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -28,8 +27,6 @@
/* All Rights Reserved */
-#pragma ident "%Z%%M% %I% %E% SMI"
-
#include <sys/param.h>
#include <sys/types.h>
#include <sys/sysmacros.h>
@@ -65,7 +62,7 @@ times(struct tms *tp)
if (copyout(&p_time, tp, sizeof (p_time)))
return (set_errno(EFAULT));
- ret_lbolt = lbolt;
+ ret_lbolt = ddi_get_lbolt();
return (ret_lbolt == -1 ? 0 : ret_lbolt);
}
@@ -95,7 +92,7 @@ times32(struct tms32 *tp)
if (copyout(&p_time, tp, sizeof (p_time)))
return (set_errno(EFAULT));
- ret_lbolt = (clock32_t)lbolt;
+ ret_lbolt = (clock32_t)ddi_get_lbolt();
return (ret_lbolt == (clock32_t)-1 ? 0 : ret_lbolt);
}
diff --git a/usr/src/uts/common/syscall/uadmin.c b/usr/src/uts/common/syscall/uadmin.c
index a9aaff7892..1bdfbbfd0b 100644
--- a/usr/src/uts/common/syscall/uadmin.c
+++ b/usr/src/uts/common/syscall/uadmin.c
@@ -24,7 +24,6 @@
* Use is subject to license terms.
*/
-
#include <sys/param.h>
#include <sys/types.h>
#include <sys/sysmacros.h>
@@ -113,8 +112,8 @@ killall(zoneid_t zoneid)
} else {
sigtoproc(p, NULL, SIGKILL);
mutex_exit(&p->p_lock);
- (void) cv_timedwait(&p->p_srwchan_cv, &pidlock,
- lbolt + hz);
+ (void) cv_reltimedwait(&p->p_srwchan_cv,
+ &pidlock, hz, TR_CLOCK_TICK);
p = practive;
}
} else {
diff --git a/usr/src/uts/common/syscall/poll.c b/usr/src/uts/common/syscall/poll.c
index f1002f69b4..bed14f800a 100644
--- a/usr/src/uts/common/syscall/poll.c
+++ b/usr/src/uts/common/syscall/poll.c
@@ -323,10 +323,11 @@ poll_common(pollfd_t *fds, nfds_t nfds, timespec_t *tsp, k_sigset_t *ksetp)
t->t_hold = *ksetp;
t->t_flag |= T_TOMASK;
/*
* Call cv_timedwait_sig() just to check for signals.
* We will return immediately with either 0 or -1.
*/
- if (!cv_timedwait_sig(&t->t_delay_cv, &p->p_lock, lbolt)) {
+ if (!cv_reltimedwait_sig(&t->t_delay_cv, &p->p_lock, 0,
+ TR_CLOCK_TICK)) {
mutex_exit(&p->p_lock);
error = EINTR;
goto pollout;
@@ -323,10 +323,11 @@ poll_common(pollfd_t *fds, nfds_t nfds, timespec_t *tsp, k_sigset_t *ksetp)
t->t_flag |= T_TOMASK;
/*
- * Call cv_timedwait_sig() just to check for signals.
+ * Call cv_reltimedwait_sig() just to check for signals.
* We will return immediately with either 0 or -1.
*/